# Copyright © 2011 Niels Thykier <niels@thykier.net>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, you can find it on the World Wide
# Web at http://www.gnu.org/copyleft/gpl.html, or write to the Free
# Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
# MA 02110-1301, USA.

package Lintian::Output::FullEWI;

# The FullEWI always emit *full* package metadata even if it is
# redundant (that is, optional values are always included) when
# emitting tags.
#   Other than that, it is identical to the normal output.
#
# When parsing a lintian.log written in format, it is no longer
# ambiguous which package is referred to (even if --verbose is
# not used).
#
# The full format of the emitted tag is:
#
#  C: name type (version) [arch]: tag [...]
#
# Note the "[...]" is the extra which may or may not be present
# depending on the tag.
#
# Notable cases:
# * binary packages include type classification
# * source packages include an architecture, which is always
#   "source".
# * "[arch]" may contain spaces (and generally do for .changes)
#   files.
# * "(version)" may contain colon (i.e. epoch versions)

use strict;
use warnings;

use Moo;
use namespace::clean;

with 'Lintian::Output';

=head1 NAME

Lintian::Output::FullEWI -- output module

=head1 SYNOPSIS

 use Lintian::Output::FullEWI;

=head1 DESCRIPTION

A parent class specializing in Lintian output.

=head1 INSTANCE METHODS

=over 4

=cut

# Overridden from Lintian::Output
sub _format_pkg_info {
    my ($self, $processable, $tag_info, $override) = @_;
    my $code = $tag_info->code;
    $code = 'X' if $tag_info->experimental;
    $code = 'O' if defined $override;
    my $version = $processable->pkg_version;
    my $arch = '';
    my $type = $processable->type;
    $arch = $processable->pkg_arch if $processable->type ne 'source';
    $arch = 'source' unless $arch;
    return "$code: " . $processable->name . " $type ($version) [$arch]";
}

=back

=head1 SEE ALSO

lintian(1)

=cut

1;

# Local Variables:
# indent-tabs-mode: nil
# cperl-indent-level: 4
# End:
# vim: syntax=perl sw=4 sts=4 sr et
